@@ -1,4 +1,4 @@
-from typing import Dict, Any, AsyncGenerator, final, Final
+from typing import Dict, Any, AsyncGenerator, final, Final, Optional
 from codaio_exporter.api.client import Client
 from codaio_exporter.api.parse import parse_str
 from codaio_exporter.api.table import TableAPI
@@ -23,8 +23,11 @@ class DocAPI:
     def folder_id(self) -> str:
         return parse_str(self._data["folder"]["id"])
     
-    def folder_name(self) -> str:
-        return parse_str(self._data["folder"]["name"])
+    def folder_name(self) -> Optional[str]:
+        if "name" in self._data["folder"]:
+            return parse_str(self._data["folder"]["name"])
+        else:
+            return None
 
     async def get_all_tables(self) -> AsyncGenerator[TableAPI, None]:
         async for table in self._client.get_list(f"{self._api_root}/tables"):
