@@ -7,9 +7,15 @@ class RowAPI:
     def __init__(self, data: Dict[str, Any]):
         self._data: Final = data
 
+    def raw_data(self) -> Dict[str, Any]:
+        return self._data
+
     def id(self) -> str:
         return parse_str(self._data["id"])
     
+    def name(self) -> str:
+        return parse_str(self._data["name"])
+    
     def index(self) -> int:
         return parse_int(self._data["index"])
     
